@@ -58,7 +58,7 @@ PREDEFINED_ENGINES = {'tesseract': {'name': 'Tesseract',
                       'gocr': {'name': 'GOCR',
                                'image_format': 'PPM',
                                'engine_path': 'gocr',
-                               'arguments': '-f UTF8 $IMAGE',
+                               'arguments': '$IMAGE -f UTF8',
                                'old_arguments': [],
                                'version': 0.0},
                       'cuneiform': {'name': 'Cuneiform',
